==> schooltool_0.11.2.orig.tar.gz: schooltool-0.11.2/src/schoolbell/app/rest/interfaces.py <==
#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2005 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
SchoolBell REST interfaces
"""

from zope.interface import Interface, Attribute

class IPasswordWriter(Interface):
    """Interface for writing password through REST."""

    def setPassword(password):
        """Set the password of the person."""


class IPersonPhoto(Interface):
    """Interface for writing and reading of Person photo."""

    def writePhoto(data):
        """Set the photo of the person."""

    def deletePhoto():
        """Clears the photo of the person."""

    def getPhoto():
        """Read the photo of the person."""


class IPersonPreferencesAdapter(Interface):
    """Interface for PersonPreferencesAdapter."""

    person = Attribute("""Person with preferences.""")

==> schooltool_0.11.4.orig.tar.gz: schooltool-0.11.4/src/schoolbell/app/rest/interfaces.py <==
#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2005 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
SchoolBell REST interfaces
"""

from zope.interface import Interface, Attribute
from zope.publisher.interfaces.http import IHTTPRequest


class IRESTRequest(IHTTPRequest):
    """Request type for the RESTive interface."""


class IPasswordWriter(Interface):
    """Interface for writing password through REST."""

    def setPassword(password):
        """Set the password of the person."""


class IPersonPhoto(Interface):
    """Interface for writing and reading of Person photo."""

    def writePhoto(data):
        """Set the photo of the person."""

    def deletePhoto():
        """Clears the photo of the person."""

    def getPhoto():
        """Read the photo of the person."""


class IPersonPreferencesAdapter(Interface):
    """Interface for PersonPreferencesAdapter."""

    person = Attribute("""Person with preferences.""")
